jupyterlab_widgets: A JupyterLab extension for Jupyter/IPython widgets
======================================================================

Description
-----------

A JupyterLab extension for Jupyter/IPython widgets.

License
-------

BSD License

Upstream Contact
----------------

Home page: https://github.com/jupyter-widgets/ipywidgets

Dependencies
------------

- jupyterlab
- nodejs
